.. Django Helpcenter documentation master file, created by
   sphinx-quickstart on Fri Sep 23 10:09:24 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

Contents:

.. toctree::
   :maxdepth: 2

   installation
   configuration
   release notes



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

